@@ -79,7 +79,7 @@ namespace Rcpp{
 
         SEXP operator()() const {
             Shield<SEXP> call(Rf_lang1(Storage::get__()));
-            return Rcpp_eval(call);
+            return Rcpp_fast_eval(call, R_GlobalEnv);
         }
 
         #include <Rcpp/generated/Function__operator.h>
@@ -111,6 +111,14 @@ namespace Rcpp{
             Shield<SEXP> x( Rf_findFun( nameSym, env ) ) ;
             Storage::set__(x) ;
         }
+
+        SEXP invoke(SEXP args_, SEXP env) const {
+            Shield<SEXP> args(args_);
+            Shield<SEXP> call(Rcpp_lcons(Storage::get__(), args));
+            SEXP out = Rcpp_fast_eval(call, env);
+            return out;
+        }
+
     };
 
     typedef Function_Impl<PreserveStorage> Function ;
