@@ -2,7 +2,8 @@
 //
 // Rstreambuf.h: Rcpp R/C++ interface class library -- stream buffer
 //
-// Copyright (C) 2011 - 2017  Dirk Eddelbuettel, Romain Francois and Jelmer Ypma
+// Copyright (C) 2011 - 2020  Dirk Eddelbuettel, Romain Francois and Jelmer Ypma
+// Copyright (C) 2021         Dirk Eddelbuettel, Romain Francois, Jelmer Ypma and Iñaki Ucar
 //
 // This file is part of Rcpp.
 //
@@ -33,47 +34,38 @@ namespace Rcpp {
         Rstreambuf(){}
 
     protected:
-        virtual std::streamsize xsputn(const char *s, std::streamsize n );
+        virtual std::streamsize xsputn(const char *s, std::streamsize n);
 
-        virtual int overflow(int c = traits_type::eof() );
+        virtual int overflow(int c = traits_type::eof());
 
-        virtual int sync()  ;
+        virtual int sync();
     };
 
     template <bool OUTPUT>
     class Rostream : public std::ostream {
-        typedef Rstreambuf<OUTPUT> Buffer ;
-        Buffer* buf ;
+        typedef Rstreambuf<OUTPUT> Buffer;
+        Buffer buf;
     public:
-        Rostream() :
-            std::ostream( new Buffer ),
-            buf( static_cast<Buffer*>( rdbuf() ) )
-        {}
-        ~Rostream() {
-            if (buf != NULL) {
-                delete buf;
-                buf = NULL;
-            }
-        }
+        Rostream() : std::ostream( &buf ) {}
     };
 							// #nocov start
-    template <> inline std::streamsize Rstreambuf<true>::xsputn(const char *s, std::streamsize num ) {
-        Rprintf( "%.*s", num, s ) ;
-        return num ;
+    template <> inline std::streamsize Rstreambuf<true>::xsputn(const char *s, std::streamsize num) {
+        Rprintf("%.*s", num, s);
+        return num;
     }
-    template <> inline std::streamsize Rstreambuf<false>::xsputn(const char *s, std::streamsize num ) {
-        REprintf( "%.*s", num, s ) ;
-        return num ;
+    template <> inline std::streamsize Rstreambuf<false>::xsputn(const char *s, std::streamsize num) {
+        REprintf("%.*s", num, s);
+        return num;
     }
 
-    template <> inline int Rstreambuf<true>::overflow(int c ) {
+    template <> inline int Rstreambuf<true>::overflow(int c) {
         if (c != traits_type::eof()) {
             char_type ch = traits_type::to_char_type(c);
             return xsputn(&ch, 1) == 1 ? c : traits_type::eof();
         }
         return c;
     }
-    template <> inline int Rstreambuf<false>::overflow(int c ) {
+    template <> inline int Rstreambuf<false>::overflow(int c) {
         if (c != traits_type::eof()) {
             char_type ch = traits_type::to_char_type(c);
             return xsputn(&ch, 1) == 1 ? c : traits_type::eof();
@@ -81,17 +73,22 @@ namespace Rcpp {
         return c;
     }
 
-    template <> inline int Rstreambuf<true>::sync(){
-        ::R_FlushConsole() ;
-        return 0 ;
+    template <> inline int Rstreambuf<true>::sync() {
+        ::R_FlushConsole();
+        return 0;
     }
-    template <> inline int Rstreambuf<false>::sync(){
-        ::R_FlushConsole() ;
-        return 0 ;
+    template <> inline int Rstreambuf<false>::sync() {
+        ::R_FlushConsole();
+        return 0;
     }								// #nocov end
-    static Rostream<true>  Rcout;
-    static Rostream<false> Rcerr;
 
+#ifdef RCPP_USE_GLOBAL_ROSTREAM
+    extern Rostream<true>&  Rcout;
+    extern Rostream<false>& Rcerr;
+#else
+    static Rostream<true>   Rcout;
+    static Rostream<false>  Rcerr;
+#endif
 
 }
 
